==> owncloud-4.0.4.tgz: owncloud/settings/l10n/gl.php <==
<?php $TRANSLATIONS = array(
"OpenID Changed" => "Mudou o OpenID",
"Invalid request" => "Petición incorrecta",
"Language changed" => "O idioma mudou",
"__language_name__" => "Galego",
"Log" => "Conectar",
"More" => "Máis",
"Add your App" => "Engade o teu aplicativo",
"Select an App" => "Escolla un Aplicativo",
"-licensed" => "-licenciado",
"by" => "por",
"Documentation" => "Documentación",
"Managing Big Files" => "Xestionar Grandes Ficheiros",
"Ask a question" => "Pregunte",
"Problems connecting to help database." => "Problemas conectando coa base de datos de axuda",
"Go there manually." => "Ir manualmente.",
"Answer" => "Resposta",
"You use" => "Vostede usa",
"of the available" => "dun total de",
"Desktop and Mobile Syncing Clients" => "Cliente de sincronización de escritorio e móbil",
"Download" => "Descargar",
"Your password got changed" => "O seu contrasinal mudou",
"Unable to change your password" => "Incapaz de trocar o seu contrasinal",
"Current password" => "Contrasinal actual",
"New password" => "Novo contrasinal",
"show" => "amosar",
"Change password" => "Mudar contrasinal",
"Email" => "Correo electrónico",
"Your email address" => "O seu enderezo de correo electrónico",
"Fill in an email address to enable password recovery" => "Escriba un enderezo de correo electrónico para habilitar a recuperación do contrasinal",
"Language" => "Idioma",
"Help translate" => "Axude na tradución",
"use this address to connect to your ownCloud in your file manager" => "utilice este enderezo para conectar ao seu ownCloud no xestor de ficheiros",
"Name" => "Nome",
"Password" => "Contrasinal",
"Groups" => "Grupos",
"Create" => "Crear",
"Default Quota" => "Cuota por omisión",
"Other" => "Outro",
"Quota" => "Cota",
"Delete" => "Borrar"
);

==> owncloud-4.5.7.tgz: owncloud/settings/l10n/gl.php <==
<?php $TRANSLATIONS = array(
"Unable to load list from App Store" => "Non se puido cargar a lista desde a App Store",
"Authentication error" => "Erro na autenticación",
"Email saved" => "Correo electrónico gardado",
"Invalid email" => "correo electrónico non válido",
"OpenID Changed" => "Mudou o OpenID",
"Invalid request" => "Petición incorrecta",
"Language changed" => "O idioma mudou",
"Disable" => "Deshabilitar",
"Enable" => "Habilitar",
"Saving..." => "Gardando...",
"__language_name__" => "Galego",
"Security Warning" => "Aviso de seguridade",
"Cron" => "Cron",
"Log" => "Conectar",
"More" => "Máis",
"Add your App" => "Engade o teu aplicativo",
"Select an App" => "Escolla un Aplicativo",
"See application page at apps.owncloud.com" => "Vexa a páxina do aplicativo en apps.owncloud.com",
"Documentation" => "Documentación",
"Managing Big Files" => "Xestionar Grandes Ficheiros",
"Ask a question" => "Pregunte",
"Problems connecting to help database." => "Problemas conectando coa base de datos de axuda",
"Go there manually." => "Ir manualmente.",
"Answer" => "Resposta",
"Desktop and Mobile Syncing Clients" => "Cliente de sincronización de escritorio e móbil",
"Download" => "Descargar",
"Unable to change your password" => "Incapaz de trocar o seu contrasinal",
"Current password" => "Contrasinal actual",
"New password" => "Novo contrasinal",
"show" => "amosar",
"Change password" => "Mudar contrasinal",
"Email" => "Correo electrónico",
"Your email address" => "O seu enderezo de correo electrónico",
"Fill in an email address to enable password recovery" => "Escriba un enderezo de correo electrónico para habilitar a recuperación do contrasinal",
"Language" => "Idioma",
"Help translate" => "Axude na tradución",
"use this address to connect to your ownCloud in your file manager" => "utilice este enderezo para conectar ao seu ownCloud no xestor de ficheiros",
"Name" => "Nome",
"Password" => "Contrasinal",
"Groups" => "Grupos",
"Create" => "Crear",
"Default Quota" => "Cuota por omisión",
"Other" => "Outro",
"Quota" => "Cota",
"Delete" => "Borrar"
);
